@@ -162,6 +162,7 @@ class Prototype(BaseAPIObject):
     id = None
     prototype_id = None
     name = None
+    display_name = None
     type = None
     description = None
     version = None
@@ -425,7 +426,7 @@ class _BaseObject(BaseAPIObject):
             object_id=self.id,
             object_type=self.prototype().type,
             name=name,
-            description=description
+            description=description,
         )
 
     @min_server_version('2021.07.16.09')
@@ -1024,10 +1025,11 @@ class Action(BaseAPIObject):
         """Return 'TaskList' object"""
         return self._child_obj(TaskList, **args)
 
-    def run(self, **args) -> "Task":
+    def run(self, **args) -> "Task":  # pylint: disable=too-many-branches
+        attach_to_allure = args.pop("attach_to_allure", True)
         with allure_step(f"Run action {self.name}"):
 
-            if 'hc' in args:
+            if 'hc' in args and attach_to_allure:
                 allure_attach_json(args.get('hc'), name="Hostcomponent map")
 
             if 'config' in args and 'config_diff' in args:
@@ -1038,6 +1040,15 @@ class Action(BaseAPIObject):
 
                 if 'config_diff' in args:
                     config_diff = args.pop('config_diff')
+                    if attach_to_allure:
+                        allure_attach_json(config_diff, name="Action config")
+                    if 'config' in config_diff and 'attr' in config_diff:
+                        args['attr'] = {}
+                        for item in self.config["attr"]:
+                            args['attr'][item] = (
+                                config_diff['attr'].get(item) or self.config['attr'][item]
+                            )
+                        config_diff = config_diff['config']
                     for item in self.config['config']:
                         if item['type'] == 'group':
                             continue
@@ -1121,11 +1132,11 @@ class Task(BaseAPIObject):
 
     def job(self, **args) -> "Job":
         """Return 'Job' object"""
-        return Job(self._api, path_args=dict(task_id=self.id), **args)
+        return Job(self._api, task_id=self.id, **args)
 
     def job_list(self, paging=None, **args) -> "JobList":
         """Return list of 'Job' objects"""
-        return JobList(self._api, paging=paging, path_args=dict(task_id=self.id), **args)
+        return JobList(self._api, paging=paging, task_id=self.id, **args)
 
     @allure_step("Wait for task end")
     def wait(self, timeout=None, log_failed=True):
@@ -1230,10 +1241,6 @@ class Job(BaseAPIObject):
     def __repr__(self):
         return f"<Job {self.job_id} at {id(self)}>"
 
-    # FIXME: remove method __init__, deal with argument path_args
-    def __init__(self, api: ADCMApiWrapper, path=None, path_args=None, **args):
-        super().__init__(api, path, **args)
-
     def task(self) -> "Task":
         """Return 'Task' object"""
         return self._parent_obj(Task)
